@@ -6,7 +6,6 @@ use std::os::unix;
 use std::os::unix::io::{AsRawFd, FromRawFd, IntoRawFd, RawFd};
 use std::time::Duration;
 use std::{fmt, io};
-use unsafe_io::OwnsRaw;
 
 /// A Unix datagram socket.
 ///
@@ -253,9 +252,6 @@ impl IntoFd for UnixDatagram {
     }
 }
 
-// Safety: `UnixDatagram` wraps a `net::UnixDatagram` which owns its handle.
-unsafe impl OwnsRaw for UnixDatagram {}
-
 impl fmt::Debug for UnixDatagram {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
         self.std.fmt(f)
